Example
=======

.. code:: django

  {% load icons %}

  <!-- Font Awesome CSS -->
  <link href="https://maxcdn.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css"
        rel="stylesheet"
        integrity="sha384-wvfXpqpZZVQGK6TAh5PVlGOfQNHSoD2xbE+QkPxCAFlNEevoEH3Sl0sibVcOQVnN"
        crossorigin="anonymous"
  >

  {% icon 'pencil' %}

  {# Read the documentation for more information #}
